%---------------------------------------------------------------------
% function[test_decis] = PP_FB_UR_test(testval,deter,kern,b,testtype,detrendmeth,alphavec);
%
% Function to compute PP unit root test decision (1 = rejection, 0 = no
% rejection) 
% Input:   testval ... value of test statistics (in R^{nr. test \times 1})
%            deter ... Specification of deterministic components:
%                             -1 ... no deterministic
%                              0 ... intercept
%                              1 ... intercept and linear trend
%             kern ... Kernel for long-run variance estimation
%                b ... Value of b
%         testtype ... which test is considered:
%                             pp ... Phillips-Perron t-test
%                             ppC ... Phillips-Perron coefficient test%                 
%          detrend ... Detrending method:
%                             1 ... One Step Detrending
%                             2 ... Two Step Detrending
%         alphavec ... vector in R^{numAlpha \times 1} percentiles.
%
% Output:      test_decis ... Vector in R^{numAlpha \times 1} with rejction
%                             frequencies (0=no rej., 1=rej.)
%
% Remark: the percvec used in Unit Root critical value tables is
%         percvec = [0.01 0.025 0.05 0.1 0.5 0.9 0.95 0.975 0.99]';
%--------------------------------------------------------------------------
function[test_decis] = PP_FB_UR_test(testval,deter,kern,b,testtype,detrendmeth,alphavec);

[numA,sizeA2] = size(alphavec);
[numtest,sizeT2] = size(testval);

% Loading of proper matrix with critical values:

% Specification of nomenclature for deterministic component:
if deter == -1;
    deterval = 'none';
elseif deter == 0;
    deterval = 'inter';
elseif deter == 1;
    deterval = 'trend';
end;

% Nomenclature to indicate one-step and two-step detrending:
if detrendmeth == 1;
    trendtype = 'onestep';
    prepart = 'Onestep_FB_';

elseif detrendmeth == 2;
    trendtype = 'twostep';
    prepart = 'Twostep_FB_';

end;

if isequal(testtype,'pp');
    eval(sprintf(['load ',pwd,filesep,'VoWa-FixedB-Critval_folders',filesep,trendtype,filesep,kern,filesep,prepart,kern,'_t_1000_',deterval]));
    eval(sprintf(['crittable = ',prepart,kern,'_t_1000_',deterval,';']));
        
elseif isequal(testtype,'ppC');
    eval(sprintf(['load ',pwd,filesep,'VoWa-FixedB-Critval_folders',filesep,trendtype,filesep,kern,filesep,prepart,kern,'_t_1000_',deterval]));
    eval(sprintf(['crittable = ',prepart,kern,'_coeff_1000_',deterval,';']));
    
end;

% Table format is the following: 50 times 9, 50 rows correspond to b values
% 0.02,0.04,...,1 and the 9 columns correspond to percentiles: 0.01, 0.025,
% 0.05, 0.10,...

critrow = crittable(floor(50*b),:);

for j=1:numA; % Loop over percentiles.
    
    
        if alphavec(j,1) == 0.01;
            critval = critrow(1);
        elseif alphavec(j,1) == 0.05;
            critval = critrow(3);
        elseif alphavec(j,1) == 0.1;
            critval = critrow(4);
        end;
    
    
    %Rejection decision:
    test_decis(j,:) = (testval < critval);
    
end; % End of loop over percentiles.

test_decis = mean(test_decis,2); % Column vector.
